@@ -230,10 +230,12 @@ def accumulate_dict_from_superclasses(cls, propname):
         setattr(cls, cachename, d)
     return cls.__dict__[cachename]
 
-class HasProps(object, metaclass=MetaHasProps):
+class HasProps(metaclass=MetaHasProps):
     ''' Base class for all class types that have Bokeh properties.
 
     '''
+    _initialized: bool = False
+
     def __init__(self, **properties):
         '''
 
@@ -246,6 +248,8 @@ class HasProps(object, metaclass=MetaHasProps):
         for name, value in properties.items():
             setattr(self, name, value)
 
+        self._initialized = True
+
     def __setattr__(self, name, value):
         ''' Intercept attribute setting on HasProps in order to special case
         a few situations:
