@@ -26,12 +26,9 @@ export class LatexLabelView extends LabelView {
 
     const panel = this.panel || this.plot_view.frame
 
-    const xscale = this.plot_view.frame.xscales[this.model.x_range_name]
-    const yscale = this.plot_view.frame.yscales[this.model.y_range_name]
-
     const {x, y} = this.model
-    let sx = this.model.x_units == "data" ? xscale.compute(x) : panel.xview.compute(x)
-    let sy = this.model.y_units == "data" ? yscale.compute(y) : panel.yview.compute(y)
+    let sx = this.model.x_units == "data" ? this.coordinates.x_scale.compute(x) : panel.xview.compute(x)
+    let sy = this.model.y_units == "data" ? this.coordinates.y_scale.compute(y) : panel.yview.compute(y)
 
     sx += this.model.x_offset
     sy -= this.model.y_offset
